Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r51842 - sandbox/tools/auto_index/src
From: john_at_[hidden]
Date: 2009-03-18 14:34:20


Author: johnmaddock
Date: 2009-03-18 14:34:18 EDT (Wed, 18 Mar 2009)
New Revision: 51842
URL: http://svn.boost.org/trac/boost/changeset/51842

Log:
Adjust which blocks get flattened, and fix bug that allowed a section to be searched more than once.
Text files modified:
   sandbox/tools/auto_index/src/auto_index.cpp | 14 ++++++++------
   1 files changed, 8 insertions(+), 6 deletions(-)

Modified: sandbox/tools/auto_index/src/auto_index.cpp
==============================================================================
--- sandbox/tools/auto_index/src/auto_index.cpp (original)
+++ sandbox/tools/auto_index/src/auto_index.cpp 2009-03-18 14:34:18 EDT (Wed, 18 Mar 2009)
@@ -185,12 +185,12 @@
    // can appear inside a <section> - see http://www.docbook.org/tdg/en/html/section.html.
    // In other words basically anything at the level of a paragraph/table/listing etc.
    //
- static const boost::array<const char*, 65> names =
+ static const boost::array<const char*, 57> names =
    {
       "title", "subtitle", "titleabbrev",
       "toc", "lot", "glossary", "bibliography",
- "calloutlist", "glosslist", "bibliolist", "itemizedlist", "orderedlist",
- "segmentedlist", "simplelist", "variablelist", "caution", "important", "note",
+ /*"calloutlist", "glosslist", "bibliolist", "itemizedlist", "orderedlist",
+ "segmentedlist", "simplelist", "variablelist",*/ "caution", "important", "note",
       "tip", "warning", "literallayout", "programlisting", "programlistingco",
       "screen", "screenco", "screenshot", "synopsis", "cmdsynopsis", "funcsynopsis",
       "classsynopsis", "fieldsynopsis", "constructorsynopsis",
@@ -199,7 +199,9 @@
       "mediaobjectco", "informalequation", "informalexample", "informalfigure",
       "informaltable", "equation", "example", "figure", "table", "msgset", "procedure",
       "sidebar", "qandaset", "task", "productionset", "constraintdef", "anchor",
- "bridgehead", "remark", "highlights", "abstract", "authorblurb", "epigraph",
+ "bridgehead", "remark", "highlights", "abstract", "authorblurb", "epigraph"
+ /*"biblioentry", "bibliomixed", "callout", "glossentry", "listitem", "seg", "seglistitem", "member",
+ "term", */
    };
    static std::set<const char*, string_cmp> terminals;
 
@@ -306,7 +308,7 @@
             //
             // We need to check to see if this term has already been indexed
             // in this zone, in order to prevent duplicate entries, also check
// that any constrait placed on the terms ID is satisfied:
             //
             std::pair<std::string, std::string> item_index(*pid, i->term);
             if(((no_duplicates == false) || (0 == found_terms.count(item_index)))
@@ -448,7 +450,7 @@
    for(boost::tiny_xml::element_list::const_iterator i = node->elements.begin();
       i != node->elements.end(); ++i)
    {
- process_node(*i, &id, &title, flatten);
+ process_node(*i, &id, &title, flatten || seen);
    }
    //
    // Process manual index entries last of all:
@@ -306,7 +308,7 @@
             // We need to check to see if this term has already been indexed
             // in this zone, in order to prevent duplicate entries, also check
- // that any constrait placed on the terms ID is satisfied:
+ // that any constrait placed on the term's ID is satisfied:
             //
             std::pair<std::string, std::string> item_index(*pid, i->term);


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk